@@ -3,5 +3,5 @@ from os import getenv
 
 NAMESPACE = 'jupyterlab-crosscompute'
 ID_LENGTH = 16
-BASE_URI = getenv('CROSSCOMPUTE_BASE_URI', '')
+ROOT_URI = getenv('CROSSCOMPUTE_ROOT_URI', '')
 PROXY_URI = 'http://localhost:6000/api/routes'
